@@ -1,4 +1,14 @@
+"unicode aid functions"
+
 def superscript(txt):
+    """put txt in superscript
+
+    a function to convert a text to supersript using unicode
+    @param txt: a string of the values to be turned into supersript
+    @type txt: string
+
+    @return: txt in superscript
+    """
     chars = {"0": "\u2070",
              "1": "\u00B9",
              "2": "\u00B2",
@@ -22,13 +32,23 @@ def superscript(txt):
     return out
 
 def prettyIndex(var):
-    "get subscript index using unicode"
+    """put txt in subscript
+
+    a function to convert a text to subscript using unicode
+    @param txt: a string of the values to be turned into subscript
+    @type txt: string
+
+    @return: txt in subscript
+    """
     #print indexes as subscript
     strIdx = ""
     for i in str(var+1):strIdx += str(chr(0x2080 + (int(i))))
     return strIdx
 
 def nroot(n):
+    """nth root print
+    
+    its ugly"""
     return superscript(n) + "\u221A"
 
              
